Index: trunk/psLib/src/math/psStats.h
===================================================================
--- trunk/psLib/src/math/psStats.h	(revision 1980)
+++ trunk/psLib/src/math/psStats.h	(revision 2204)
@@ -10,6 +10,6 @@
  *  @author George Gusciora, MHPCC
  *
- *  @version $Revision: 1.31 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-10-06 20:07:04 $
+ *  @version $Revision: 1.32 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-27 00:57:31 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -67,11 +67,11 @@
     double robustUQ;            ///< robust upper quartile
     double robustLQ;            ///< robust lower quartile
-    int robustN50;              ///<
-    int robustNfit;             ///<
+    psS32 robustN50;              ///<
+    psS32 robustNfit;             ///<
     double clippedMean;         ///< Nsigma clipped mean
     double clippedStdev;        ///< standard deviation after clipping
-    int clippedNvalues;         ///< ???
+    psS32 clippedNvalues;         ///< ???
     double clipSigma;           ///< Nsigma used for clipping; user input
-    int clipIter;               ///< Number of clipping iterations; user input
+    psS32 clipIter;               ///< Number of clipping iterations; user input
     double min;                 ///< minimum data value in array
     double max;                 ///< maximum data value in array
@@ -89,5 +89,5 @@
     psVector* in,    ///< Vector to be analysed: must be F32
     psVector* mask,    ///< Ignore elements where (maskVector & maskVal) != 0: must be INT or NULL
-    unsigned int maskVal    ///< Only mask elements with one of these bits set in maskVector
+    psU32 maskVal    ///< Only mask elements with one of these bits set in maskVector
 );
 
@@ -118,7 +118,7 @@
     psVector* bounds;                  ///< Bounds for the bins (type F32)
     psVector* nums;                    ///< Number in each of the bins (INT)
-    int minNum;                        ///< Number below the minimum
-    int maxNum;                        ///< Number above the maximum
-    bool uniform;                      ///< Is it a uniform distribution?
+    psS32 minNum;                        ///< Number below the minimum
+    psS32 maxNum;                        ///< Number above the maximum
+    psBool uniform;                      ///< Is it a uniform distribution?
 }
 psHistogram;
@@ -133,5 +133,5 @@
     float lower,                       ///< Lower limit for the bins
     float upper,                       ///< Upper limit for the bins
-    int n                              ///< Number of bins
+    psS32 n                              ///< Number of bins
 );
 
@@ -157,14 +157,14 @@
     const psVector* restrict in,       ///< Vector to analyse
     const psVector* restrict mask,     ///< Mask dat for input vector
-    unsigned int maskVal               ///< Mask value
+    psU32 maskVal               ///< Mask value
 );
 
 /** Extracts the statistic value specified by stats->options.
  *
  *  @return bool    If more than one statistic result is set in stats->options,
  *                  false is returned and the value parameter is not set, 
  *                  otherwise true is returned.
  */
-bool p_psGetStatValue(
+psBool p_psGetStatValue(
     const psStats* stats,
     ///< the statistic struct to operate on
@@ -157,14 +157,14 @@
 /** Extracts the statistic value specified by stats->options.
  *
- *  @return bool    If more than one statistic result is set in stats->options,
+ *  @return psBool    If more than one statistic result is set in stats->options,
  *                  false is returned and the value parameter is not set, 
  *                  otherwise true is returned.
